from flask import Flask

"""
Rest layer module
"""

API_PREFIX = "/api/v1.0"


def register_blueprints(app: Flask):
    """Registers blue prints for the application
    Args:
        app(Flask): Flask application
    Returns(Flask): Flask application

    """
    from portal.rest.auth.login import auth_blueprint
    from portal.rest.courses.courses import courses_blueprint
    from portal.rest.roles.roles import roles_blueprint
    from portal.rest.groups.groups import groups_blueprint
    from portal.rest.submissions.submissions import submissions_blueprint
    from portal.rest.projects.projects import projects_blueprint
    from portal.rest.components.components import components_blueprint
    from portal.rest.notifications.notifications import notifications_blueprint
    from portal.rest.users.users import users_blueprint
    app.register_blueprint(auth_blueprint, url_prefix=f"{API_PREFIX}/auth")
    app.register_blueprint(users_blueprint, url_prefix=f"{API_PREFIX}/users")
    app.register_blueprint(courses_blueprint, url_prefix=f"{API_PREFIX}/courses")
    app.register_blueprint(roles_blueprint, url_prefix=f"{API_PREFIX}/courses/<string:cid>/roles")
    app.register_blueprint(groups_blueprint, url_prefix=f"{API_PREFIX}/courses/<string:cid>/groups")
    app.register_blueprint(projects_blueprint,
                           url_prefix=f"{API_PREFIX}/courses/<string:cid>/projects")
    app.register_blueprint(submissions_blueprint, url_prefix=f"{API_PREFIX}/submissions")
    app.register_blueprint(components_blueprint, url_prefix=f"{API_PREFIX}/components")
    app.register_blueprint(notifications_blueprint, url_prefix=f"{API_PREFIX}/notifications")
    __register_gitlab_endpoint(app)
    return app


def __register_gitlab_endpoint(app: Flask):
    """Registers the gitlab endpoint only if gitlab url has been specified
    Args:
        app(Flask): Flask application
    """
    if app.config.get('GITLAB_URL'):
        from portal.rest.auth.gitlab import oauth_blueprint
        app.register_blueprint(oauth_blueprint, url_prefix=f"{API_PREFIX}/oauth")
